[![CircleCI](https://circleci.com/gh/ashat1701/rts-game/tree/dev.svg?style=svg)](https://circleci.com/gh/ashat1701/rts-game/tree/dev)
# RTS game (нет)
Простая игра о том что нужно быть сильным и справлятся с трудностями жизни
# Установка и запуск
* для Debian-based дистрибутивов
```shell
sudo apt install python3-tkinter
sudo pip3 install -r requirements.txt
python 3 ./MainMenu.py
```
* Для Windows
Нужно установить пакет 
[ActionTcl](https://www.activestate.com/products/activetcl/downloads/). Пройдите несложную регистрацию и установите TCL.
После этого аналогично инструкции для linux.
